@@ -257,6 +257,8 @@ private:
         {
             rasterY++;
             rasterYIRQEdgeDetector();
+            if ((rasterY == FIRST_DMA_LINE) && !areBadLinesEnabled)
+                areBadLinesEnabled = readDEN();
         }
 
         if (evaluateIsBadLine())
@@ -312,7 +314,7 @@ private:
 
 protected:
     MOS656X(EventScheduler &scheduler);
-    ~MOS656X() {}
+    ~MOS656X() = default;
 
     // Environment Interface
     virtual void interrupt(bool state) = 0;
