@@ -32,6 +32,8 @@
 
 #include "sidcxx11.h"
 
+#include <ctime>
+
 namespace libsidplayfp
 {
 
@@ -69,8 +71,8 @@ Player::Player() :
     // Set default settings for system
     m_tune(nullptr),
     m_errorString(ERR_NA),
-    m_isPlaying(STOPPED),
-    m_rand((unsigned int)::time(0))
+    m_isPlaying(state_t::STOPPED),
+    m_rand((unsigned int)std::time(nullptr))
 {
     // We need at least some minimal interrupt handling
     m_c64.getMemInterface().setKernal(nullptr);
@@ -126,7 +128,7 @@ bool Player::fastForward(unsigned int percent)
 
 void Player::initialise()
 {
-    m_isPlaying = STOPPED;
+    m_isPlaying = state_t::STOPPED;
 
     m_c64.reset();
 
@@ -195,7 +197,7 @@ void Player::mute(unsigned int sidNum, unsigned int voice, bool enable)
  */
 void Player::run(unsigned int events)
 {
-    for (unsigned int i = 0; m_isPlaying && i < events; i++)
+    for (unsigned int i = 0; (m_isPlaying != state_t::STOPPED) && (i < events); i++)
         m_c64.clock();
 }
 
@@ -206,10 +208,10 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
         return 0;
 
     // Start the player loop
-    if (m_isPlaying == STOPPED)
-        m_isPlaying = PLAYING;
+    if (m_isPlaying == state_t::STOPPED)
+        m_isPlaying = state_t::PLAYING;
 
-    if (m_isPlaying == PLAYING)
+    if (m_isPlaying == state_t::PLAYING)
     {
         try
         {
@@ -223,7 +225,7 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
                     count = 0;
 
                     // Clock chips and mix into output buffer
-                    while (m_isPlaying && m_mixer.notFinished())
+                    while ((m_isPlaying != state_t::STOPPED) && m_mixer.notFinished())
                     {
                         run(sidemu::OUTPUTBUFFERSIZE);
 
@@ -236,7 +238,7 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
                 {
                     // Clock chips and discard buffers
                     int size = m_c64.getMainCpuSpeed() / m_cfg.frequency;
-                    while (m_isPlaying && --size)
+                    while ((m_isPlaying != state_t::STOPPED) && --size)
                     {
                         run(sidemu::OUTPUTBUFFERSIZE);
 
@@ -249,7 +251,7 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
             {
                 // Clock the machine
                 int size = m_c64.getMainCpuSpeed() / m_cfg.frequency;
-                while (m_isPlaying && --size)
+                while ((m_isPlaying != state_t::STOPPED) && --size)
                 {
                     run(sidemu::OUTPUTBUFFERSIZE);
                 }
@@ -258,23 +260,23 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
         catch (MOS6510::haltInstruction const &)
         {
             m_errorString = "Illegal instruction executed";
-            m_isPlaying = STOPPING;
+            m_isPlaying = state_t::STOPPING;
         }
         catch (Mixer::badBufferSize const &)
         {
             m_errorString = "Bad buffer size";
-            m_isPlaying = STOPPING;
+            m_isPlaying = state_t::STOPPING;
         }
     }
 
-    if (m_isPlaying == STOPPING)
+    if (m_isPlaying == state_t::STOPPING)
     {
         try
         {
             initialise();
         }
         catch (configError const &) {}
-        m_isPlaying = STOPPED;
+        m_isPlaying = state_t::STOPPED;
     }
 
     return count;
@@ -282,9 +284,9 @@ uint_least32_t Player::play(short *buffer, uint_least32_t count)
 
 void Player::stop()
 {
-    if (m_tune != nullptr && m_isPlaying == PLAYING)
+    if ((m_tune != nullptr) && (m_isPlaying == state_t::PLAYING))
     {
-        m_isPlaying = STOPPING;
+        m_isPlaying = state_t::STOPPING;
     }
 }
 
@@ -355,7 +357,7 @@ bool Player::config(const SidConfig &cfg, bool force)
         catch (configError const &e)
         {
             m_errorString = e.message();
-            m_cfg.sidEmulation = 0;
+            m_cfg.sidEmulation = nullptr;
             if (&m_cfg != &cfg)
             {
                 config(m_cfg);
