@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- *  Copyright 2014-2022 Leandro Nini
+ *  Copyright 2014-2024 Leandro Nini
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,15 +41,7 @@
 #endif
 
 #ifndef HAVE_CXX11
-#  define nullptr    0
-#  define override
-#  define final
-#  define unique_ptr auto_ptr
-#  define DEFAULT {}
-#  define DELETE {}
-#else
-#  define DEFAULT = default
-#  define DELETE  = delete
+#  error "This is not a C++11 compiler"
 #endif
 
 
